CommandFrame

Struct CommandFrame 

pub struct CommandFrame {
    pub extended_regs: ExtendedRegs,
    pub gpregs: GpRegs,
    pub restore_extended_registers: u64,
    pub save_extended_registers: u64,
    pub memory_mappings: MemoryMappings,
    pub debug_regs: DebugRegs,
    /* private fields */
}
The command frame is structured such that important values will be nicely aligned.

The extended register data is at the front, which means it will be aligned on a page bound. The GpRegs are aligned on a 1024-byte boundary. Memory mappings and other configuration follow after that. ! NOTE: Do not modify the field order without benchmarking! Ordering the fields incorrectly can easily cost ~5-10% performance.

Fields

extended_regs: ExtendedRegs

Data for the extended registers (3072 bytes)

gpregs: GpRegs

The basic general-purpose registers (184 bytes)

restore_extended_registers: u64

The bitmask of extended registers that should be set (8 bytes)

save_extended_registers: u64

The bitmask of extended registers that should be copied back into extended_register_data (8 bytes)

memory_mappings: MemoryMappings

The memory mappings (780 bytes)

debug_regs: DebugRegs

The debugging registers DR0-DR3, DR6 & DR7 (48 bytes)

Implementations



impl CommandFrame

pub fn new( gpregs: GpRegs, memory_mappings: impl Iterator<Item = MemoryMapping>, ) -> CommandFrame