Module queue

Module queue 

A shared memory queue for communication between the host and the VM client.

Structs

Queue
A shared memory queue.

Traits

CurrentPos
A trait that returns the current read position in the queue.