CurrentPos

Trait CurrentPos 

pub trait CurrentPos: Sized {
    // Required method
    fn current_pos(control: &ControlFrame<'_, Self>) -> u32;
}
A trait that returns the current read position in the queue.

It is implemented separately for the Host and Client.

Required Methods

fn current_pos(control: &ControlFrame<'_, Self>) -> u32

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors