Crate liblisa_x64_observer_shmqueue
liblisa_
x64_
observer_
shmqueue
0.3.1
All Items
Crate Items
Modules
Crate
liblisa_
x64_
observer_
shmqueue
Modules

frame
Types representing the frames in the shared memory queue.
queue
A shared memory queue for communication between the host and the VM client.
regs
Registers in the command frames.