Module queue
A shared memory queue for communication between the host and the VM client.
Structs
- Queue
- A shared memory queue.
Traits
- Current
Pos - A trait that returns the current read position in the queue.
A shared memory queue for communication between the host and the VM client.